package com.zd.laboratory.service;

import com.zd.laboratory.domain.LabSensor;
import com.zd.laboratory.domain.vo.LabSensorVO;
import com.zd.system.api.laboratory.domain.SensorFunctionStatus;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 传感器Service接口
 *
 * @author zd
 * @date 2021-08-30
 */
public interface ILabSensorService {
    /**
     * 查询传感器
     *
     * @param id 传感器主键
     * @return 传感器
     */
    public LabSensor selectLabSensorById(Long id);

    int selectSensorCountBySubIds(Long subjectId);


    /**
     * 查询传感器列表
     *
     * @param labSensor 传感器
     * @return 传感器集合
     */
    public List<LabSensorVO> selectLabSensorList(LabSensor labSensor);

    /**
     * 查询传感器列表
     *
     * @param labSensor 传感器
     * @return 传感器集合
     */
    public List<LabSensorVO> selectLabSensorList(LabSensor labSensor,int countNum,Long subjectId);

    /**
     * 新增传感器
     *
     * @param labSensor 传感器
     * @return 结果
     */
    public int insertLabSensor(LabSensor labSensor);

    /**
     * 根据网关编码获取实验室ID
     * @param GatewayNum
     * @return
     */
    public Long getCacheSubByGateway(String GatewayNum);
    /**
     * 修改传感器
     *
     * @param labSensor 传感器
     * @return 结果
     */
    public int updateLabSensor(LabSensor labSensor);

    /**
     * 批量删除传感器
     *
     * @param ids 需要删除的传感器主键集合
     * @return 结果
     */
    public int deleteLabSensorByIds(Long[] ids);

    /**
     * 删除传感器信息
     *
     * @param id 传感器主键
     * @return 结果
     */
    public int deleteLabSensorById(Long id);


    /**
     * 查询传感器功能列表
     *
     * @return 功能集合
     */
    public List<SensorFunctionStatus> getFunList();
}
